import { Promise } from "./Promise";
/** A static class that wraps simple request methods to send and receive data asynchronously */
export declare class Http {
    /** Perform a GET request with given parameters and headers, if any; returns a promise that resolves to the response text */
    static getText(url: string, params?: any, headers?: Http.Headers): Promise<string>;
    /** Perform a GET request with given parameters and headers, if any; returns a promise that resolves to the parsed JSON response */
    static get(url: string, params?: any, headers?: Http.Headers): Promise<any>;
    /** Perform a POST request with given object (sent as JSON) and headers, if any; returns a promise that resolves to the parsed JSON response */
    static post(url: string, data?: any, headers?: Http.Headers): Promise<any>;
    /** Perform a PUT request with given object (sent as JSON) and headers, if any; returns a promise that resolves to the parsed JSON response */
    static put(url: string, data?: any, headers?: Http.Headers): Promise<any>;
    /** Perform a DELETE request with given object (sent as JSON) and headers, if any; returns a promise that resolves to the parsed JSON response */
    static delete(url: string, data?: any, headers?: Http.Headers): Promise<any>;
    /** Perform a GET request with given parameters and headers, if any; returns a promise that resolves to the parsed HTML result body as a document fragment (ignores everything before and after body tag, if any; inserts everything if no body tag is found, i.e. partial HTML) */
    static getHtmlContent(url: string, params?: any, headers?: Http.Headers): Promise<DocumentFragment>;
}
export declare namespace Http {
    /** Definition of a collection of HTTP headers as an object */
    interface Headers {
        [name: string]: string;
    }
}
